#!/bin/bash


#  Slackbuild script for jhead
# Author: Mark Tucker
# Created: Aug 27, 2005
# Changes:
#        Aug 27, 2005 - initial creation
#
#----------------------------------------------------------------------
umask 0022

#----------------------------------------
# include the common functions
#----------------------------------------
if [ -r ./sbuild.functions ]; then
    . ./sbuild.functions
else
    echo Cannot read file `pwd`/sbuild.functions
    echo Exiting....
    echo
    exit
fi

#----------------------------------------
# Set locations for temp directories
#----------------------------------------
# location of source code archive
srcdir=`pwd`/SRC
workdir=`pwd`


#----------------------------------------
# Package variables
#----------------------------------------
source="jhead-2.4.tar.gz"
pkgname="jhead"
pkgver="2.4"
release="1mht"
package="$pkgname-$pkgver-i486-$release.tgz"
realname="Mark Tucker"
echo Package: $package

#----------------------------------------
# setup path variables
#----------------------------------------
set_workdir

# unpack the source
echo Unpacking the source...
tar -xzf $srcdir/$source


cd $builddir

#----------------------------------------
# setup the build environment
#----------------------------------------
export CFLAGS="-O2 -march=i486 -mcpu=i686"
export CPPFLAGS="-O2 -march=i486 -mcpu=i686"
export CXXFLAGS=$CPPFLAGS

# sorry not an autoconf package...
make

# Set target directory
set_target

# install files
mkdir -p $target/usr/bin
cp -v $builddir/jhead $target/usr/bin
chmod 0755 $target/usr/bin/jhead

mkdir -p $target/usr/man/man1
cp -v $builddir/jhead.1.gz $target/usr/man/man1/


echo finishing install...


# create install dir
mkdir $target/install

#----------------------------------------
# create slack-desc file to install
#----------------------------------------
cat > $target/install/slack-desc << END
             |-----handy-ruler------------------------------------------------------|
$pkgname: $pkgname $pkgver 
$pkgname:
$pkgname: Exif Jpeg camera setting parser and thumbnail remover Version 2.4-1
$pkgname: 
$pkgname: 
$pkgname: 
$pkgname:
$pkgname:
$pkgname: http://www.sentex.net/~mwandel/jhead/
$pkgname:
$pkgname: Packaged by $realname for $slackver 
END


# create documentation directory
create_docdir

cp $builddir/readme.txt $docdir/
cp $builddir/changes.txt $docdir/
cp $builddir/usage.html $docdir/

# fix group on bin directories.
fix_bingrp

# strip  bin files
strip_bin

# strip lib files
strip_libs

# makepkg
create_pkg

exit